# Coordinate spaces

## Image domain

```{eval-rst}
.. automodule:: deepali.core.Cube
    :noindex:
```

## Image grid

```{eval-rst}
.. automodule:: deepali.core.Grid
    :noindex:
```

## Grid axes

```{eval-rst}
.. automodule:: deepali.core.Axes
    :noindex:

.. autoattribute:: deepali.core.Axes.CUBE
    :noindex:

.. autoattribute:: deepali.core.Axes.CUBE_CORNERS
    :noindex:

.. autoattribute:: deepali.core.Axes.GRID
    :noindex:

.. autoattribute:: deepali.core.Axes.WORLD
    :noindex:
```
